pub struct ClosedChannelUpdate {
pub chan_id: u64,
pub capacity: i64,
pub closed_height: u32,
pub chan_point: Option<ChannelPoint>,
}Fields
chan_id: u64The unique channel ID for the channel. The first 3 bytes are the block height, the next 3 the index within the block, and the last 2 bytes are the output index for the channel.
capacity: i64closed_height: u32chan_point: Option<ChannelPoint>Trait Implementations
Sourceimpl Clone for ClosedChannelUpdate
impl Clone for ClosedChannelUpdate
Sourcefn clone(&self) -> ClosedChannelUpdate
fn clone(&self) -> ClosedChannelUpdate
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClosedChannelUpdate
impl Debug for ClosedChannelUpdate
Sourceimpl Default for ClosedChannelUpdate
impl Default for ClosedChannelUpdate
Sourcefn default() -> ClosedChannelUpdate
fn default() -> ClosedChannelUpdate
Returns the “default value” for a type. Read more
Sourceimpl Message for ClosedChannelUpdate
impl Message for ClosedChannelUpdate
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ClosedChannelUpdate
impl PartialEq for ClosedChannelUpdate
impl StructuralPartialEq for ClosedChannelUpdate