pub struct ConfirmationUpdate {
pub block_sha: Vec<u8>,
pub block_height: i32,
pub num_confs_left: u32,
}Fields
block_sha: Vec<u8>block_height: i32num_confs_left: u32Trait Implementations
Sourceimpl Clone for ConfirmationUpdate
impl Clone for ConfirmationUpdate
Sourcefn clone(&self) -> ConfirmationUpdate
fn clone(&self) -> ConfirmationUpdate
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConfirmationUpdate
impl Debug for ConfirmationUpdate
Sourceimpl Default for ConfirmationUpdate
impl Default for ConfirmationUpdate
Sourcefn default() -> ConfirmationUpdate
fn default() -> ConfirmationUpdate
Returns the “default value” for a type. Read more
Sourceimpl Message for ConfirmationUpdate
impl Message for ConfirmationUpdate
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ConfirmationUpdate
impl PartialEq for ConfirmationUpdate
impl StructuralPartialEq for ConfirmationUpdate