pub struct MppRecord {
pub payment_addr: Vec<u8>,
pub total_amt_msat: i64,
}Fields
payment_addr: Vec<u8>A unique, random identifier used to authenticate the sender as the intended payer of a multi-path payment. The payment_addr must be the same for all subpayments, and match the payment_addr provided in the receiver’s invoice. The same payment_addr must be used on all subpayments.
total_amt_msat: i64The total amount in milli-satoshis being sent as part of a larger multi-path payment. The caller is responsible for ensuring subpayments to the same node and payment_hash sum exactly to total_amt_msat. The same total_amt_msat must be used on all subpayments.